@@ -131,9 +131,10 @@ class CustomHookPlugin(HookPluginBase):
         try:
             if hook_def.command is None:
                 return HookResult(
+                    id=f"hook_{hook_def.name}",
                     name=hook_def.name,
                     status="failed",
-                    message="Hook command is None",
+                    issues_found=["Hook command is None"],
                     duration=0.0,
                 )
             cmd = hook_def.command.copy()
